@@ -1,6 +1,6 @@
 package WebService::Solr;
 
-use Moose;
+use Any::Moose;
 
 use Encode qw(encode);
 use URI;
@@ -35,7 +35,7 @@ has 'last_response' => (
     isa => 'Maybe[WebService::Solr::Response]',
 );
 
-our $VERSION = '0.15';
+our $VERSION = '0.17';
 
 sub BUILDARGS {
     my ( $self, $url, $options ) = @_;
@@ -158,7 +158,9 @@ sub generic_solr_request {
     $params ||= {};
     return $self->last_response(
         WebService::Solr::Response->new(
-            $self->agent->get( $self->_gen_url( $path, $params ) ) ) );
+            $self->agent->post(
+                $self->_gen_url( $path ),
+                $params ) ) );
 }
 
 sub _gen_url {
@@ -194,7 +196,7 @@ sub _send_update {
     return $self->last_response;
 }
 
-no Moose;
+no Any::Moose;
 
 __PACKAGE__->meta->make_immutable;
 
